# Visualizations (Viz)

## `valency-anndata` methods

<!-- Need to do this due to something unconventional we're doing with this module. -->
<!-- TODO: Figure out what's going on here. -->
### ::: valency_anndata.viz.schematic_diagram.schematic_diagram
    options:
        heading: valency_anndata.viz.schematic_diagram
        show_overloads: false

### ::: valency_anndata.viz.voter_vignette_browser

### ::: valency_anndata.viz.jscatter

### ::: valency_anndata.viz.langevitour

## `scanpy` methods (inherited)

!!! note

    These methods are simply quick convenience wrappers around methods in `scanpy`, a tool for single-cell gene expression. They will use terms like "cells", "genes" and "counts", but you can think of these as "participants", "statements" and "votes".  

See [scanpy.pl][] for more methods you can experiment with via the `val.scanpy.pl` namespace.

### ::: valency_anndata.viz.pca

### ::: valency_anndata.viz.umap

### ::: valency_anndata.viz.embedding